# Spiel

![PyPI](https://img.shields.io/pypi/v/spiel)
[![Documentation Status](https://readthedocs.org/projects/spiel/badge/?version=latest)](https://spiel.readthedocs.io/en/latest/?badge=latest)
![PyPI - License](https://img.shields.io/pypi/l/spiel)

[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/JoshKarpel/spiel/main.svg)](https://results.pre-commit.ci/latest/github/JoshKarpel/spiel/main)
[![codecov](https://codecov.io/gh/JoshKarpel/spiel/branch/main/graph/badge.svg?token=2sjP4V0AfY)](https://codecov.io/gh/JoshKarpel/spiel)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

![GitHub issues](https://img.shields.io/github/issues/JoshKarpel/spiel)
![GitHub pull requests](https://img.shields.io/github/issues-pr/JoshKarpel/spiel)

Spiel is a framework for building and presenting richly-styled presentations in your terminal using Python.

To see what Spiel can do, install it (`pip install spiel`), then run this command to view the demonstration deck:
```bash
$ spiel demo present
```
